/*
pbprob.c  Version 0.3.0 Print Powerball Odds
Copyright (C) 2002-2010   dondalah721@yahoo.com (Dondalah)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to:

	Free Software Foundation, Inc.
	59 Temple Place - Suite 330
	Boston, MA  02111-1307, USA.
*/

/*
Subroutine call:
    	int select;
    	int pwrball;
    	double odds;
    	double getpb(int select, int pwrball);
    	odds = getpb(select,pwrball);
*/

/* The mathematics for calculating the odds */
/* in this program is based on: */
/* Lincoln L. Chao */
/* Statistics for Management */
/* 2nd Edition */
/* Palo Alto: The Scientific Press, 1984 */
/* Lincoln L. Chao published this book while at */
/* California State University, Long Beach. */
/* Chapter 4, Events and Probabilities */
/* Section 3, Computing Probability */
/* Example 4-13, Part 2 */

#include <stdio.h>

int main()
   {
   double odds;
   double getpb(int select, int pwrball);
   /******************************************************/
   /*                                                    */
   /* See the documentation in combo.c */
   /*                                                    */
   /* Odds for Grand Prize, match all 5 and big ball     */
   /*                                                    */
   /*          C(5,5)  * C(1,1)          1    * 1        */
   /*         ------------------  =  -------------       */
   /*          C(45,5) * C(45,1)      1221759 * 45       */
   /*                                                    */
   /*        = 1 / 54979155                              */
   /*                                                    */
   odds = getpb(5,1);
   printf("Prize          Odds\n");
   printf("5 1 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for 2nd Prize, match all 5 and no big ball    */
   /*                                                    */
   /*          C(5,5)  * C(44,1)         1    * 44       */
   /*         ------------------  =  -------------       */
   /*          C(45,5) * C(45,1)      1221759 * 45       */
   /*                                                    */
   /*        = 1 / 1249526.25                            */
   /*                                                    */
   odds = getpb(5,0);
   printf("5 0 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 4 numbers and big ball           */
   /*                                                    */
   /*          C(5,4) * C(40,1) * C(1,1)                 */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           5 * 40    * 1                            */
   /*        = ---------------                           */
   /*           1221759   * 45                           */
   /*                                                    */
   /*        =  1 / 274895.775                           */
   /*                                                    */
   odds = getpb(4,1);
   printf("4 1 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 4 numbers and no big ball        */
   /*                                                    */
   /*          C(5,4) * C(40,1) * C(44,1)                */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           5 * 40    * 44                           */
   /*        = ---------------                           */
   /*           1221759   * 45                           */
   /*                                                    */
   /*        =  1 / 6247.63125                           */
   /*                                                    */
   odds = getpb(4,0);
   printf("4 0 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 3 numbers and big ball           */
   /*                                                    */
   /*          C(5,3) * C(40,2) * C(1,1)                 */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           10 * 780  * 1                            */
   /*        = ---------------                           */
   /*           1221759   * 45                           */
   /*                                                    */
   /*        =  1 / 7048.609615                          */
   /*                                                    */
   odds = getpb(3,1);
   printf("3 1 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 3 numbers and no big ball        */
   /*                                                    */
   /*          C(5,3) * C(40,2) * C(44,1)                */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           10 * 780  * 44                           */
   /*        = ---------------                           */
   /*           1221759   * 45                           */
   /*                                                    */
   /*        =  1 / 160.1956731                          */
   /*                                                    */
   odds = getpb(3,0);
   printf("3 0 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 2 numbers and big ball           */
   /*                                                    */
   /*          C(5,2) * C(40,3) * C(1,1)                 */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           10 * 9880  * 1                           */
   /*        = ----------------                          */
   /*           1221759    * 45                          */
   /*                                                    */
   /*        =  1 / 556.4691802                          */
   /*                                                    */
   odds = getpb(2,1);
   printf("2 1 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 1 number and big ball            */
   /*                                                    */
   /*          C(5,1) * C(40,4) * C(1,1)                 */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           5 * 91390  * 1                           */
   /*        = ----------------                          */
   /*           1221759    * 45                          */
   /*                                                    */
   /*        =  1 / 120.3176606                          */
   /*                                                    */
   odds = getpb(1,1);
   printf("1 1 %15.1f\n", odds);
   /******************************************************/
   /*                                                    */
   /* Odds for matching 0 number and big ball            */
   /*                                                    */
   /*          C(5,0) * C(40,5) * C(1,1)                 */
   /*         ---------------------------                */
   /*              C(45,5)      * C(45,1)                */
   /*                                                    */
   /*           1 * 658008  * 1                          */
   /*        = -----------------                         */
   /*           1221759     * 45                         */
   /*                                                    */
   /*        =  1 / 83.55393096                          */
   /*                                                    */
   odds = getpb(0,1);
   printf("0 1 %15.1f\n", odds);
   return(0);
   } /* main */
